@@ -19,6 +19,7 @@ from .literals import (
     ErrorCauseType,
     ExportStatusType,
     LedgerStateType,
+    PermissionsModeType,
     S3ObjectEncryptionTypeType,
     StreamStatusType,
 )
@@ -51,6 +52,7 @@ __all__ = (
     "S3EncryptionConfigurationTypeDef",
     "S3ExportConfigurationTypeDef",
     "StreamJournalToKinesisResponseTypeDef",
+    "UpdateLedgerPermissionsModeResponseTypeDef",
     "UpdateLedgerResponseTypeDef",
     "ValueHolderTypeDef",
 )
@@ -70,6 +72,7 @@ CreateLedgerResponseTypeDef = TypedDict(
         "Arn": str,
         "State": LedgerStateType,
         "CreationDateTime": datetime,
+        "PermissionsMode": PermissionsModeType,
         "DeletionProtection": bool,
     },
     total=False,
@@ -97,6 +100,7 @@ DescribeLedgerResponseTypeDef = TypedDict(
         "Arn": str,
         "State": LedgerStateType,
         "CreationDateTime": datetime,
+        "PermissionsMode": PermissionsModeType,
         "DeletionProtection": bool,
     },
     total=False,
@@ -314,6 +318,16 @@ StreamJournalToKinesisResponseTypeDef = TypedDict(
     total=False,
 )
 
+UpdateLedgerPermissionsModeResponseTypeDef = TypedDict(
+    "UpdateLedgerPermissionsModeResponseTypeDef",
+    {
+        "Name": str,
+        "Arn": str,
+        "PermissionsMode": PermissionsModeType,
+    },
+    total=False,
+)
+
 UpdateLedgerResponseTypeDef = TypedDict(
     "UpdateLedgerResponseTypeDef",
     {
